# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [1.5] - 2025-12-29
### Added
- `--intensity` argument
- `--once` argument
- Light colors
### Changed
- `README.md` updated
- Test system modified
- `notebook.ipynb` updated
## [1.4] - 2025-12-16
### Added
- `--color` argument
- `--bg-color` argument
### Changed
- `README.md` updated
- Test system modified
## [1.3] - 2025-11-28
### Added
- `notebook.ipynb`
- Jupyter notebook support
- `detect_environment` function
### Changed
- `clear_screen` function modified
- `run_clock` function modified
- `print_calendar` function modified
- `Python 3.14` added to `test.yml`
- `README.md` updated
## [1.2] - 2025-09-02
### Added
- `--offset-local` argument
- `--offset-timezone` argument
### Changed
- `README.md` updated
- Test system modified
- `_get_weekday_id` function renamed to `get_weekday_id`
- `clox_info` function renamed to `print_clox_info`
## [1.1] - 2025-05-23
### Added
- `--first-weekday` argument
- `--date-format` argument
- `--date-formats-list` argument
### Changed
- `README.md` updated
- Test system modified
## [1.0] - 2025-05-06
### Added
- Local time
### Changed
- `clox_info` function modified
- `run_clock` function modified
## [0.9] - 2025-04-14
### Added
- Timezone difference
### Changed
- Python typing features added to all modules
- Test system modified
- `Python 3.6` support dropped
## [0.8] - 2025-03-16
### Added
- `--country` argument
- `--countries-list` argument
- `COUNTRIES.md`
### Changed
- Input case sensitivity bug fixed
- Test system modified
- `README.md` updated
## [0.7] - 2025-03-06
### Added
- Jalali calendar
- `--date-system` argument
### Changed
- `README.md` updated
## [0.6] - 2025-02-25
### Added
- `--calendar` argument
### Changed
- `README.md` updated
## [0.5] - 2025-02-14
### Added
- `--hide-date` argument
- `--hide-timezone` argument
- `--am-pm` argument
### Changed
- `README.md` updated
## [0.4] - 2025-01-18
### Added
- Date
- `--info` argument
## [0.3] - 2025-01-10
### Added
- Logo
- `--vertical` argument
### Changed
- `show_faces_list` function updated
- `AUTHORS.md` updated
## [0.2] - 2025-01-01
### Added
- Blink mode
- `--no-blink` argument
### Changed
- `README.md` updated
## [0.1] - 2024-12-24
### Added
- `--v-shift` and `--h-shift` arguments
- `--timezone` argument
- `--face` argument
- `run_clock` and `main` functions
- `TIMEZONES.md`
- `FACES.md`

[Unreleased]: https://github.com/sepandhaghighi/clox/compare/v1.5...dev
[1.5]: https://github.com/sepandhaghighi/clox/compare/v1.4...v1.5
[1.4]: https://github.com/sepandhaghighi/clox/compare/v1.3...v1.4
[1.3]: https://github.com/sepandhaghighi/clox/compare/v1.2...v1.3
[1.2]: https://github.com/sepandhaghighi/clox/compare/v1.1...v1.2
[1.1]: https://github.com/sepandhaghighi/clox/compare/v1.0...v1.1
[1.0]: https://github.com/sepandhaghighi/clox/compare/v0.9...v1.0
[0.9]: https://github.com/sepandhaghighi/clox/compare/v0.8...v0.9
[0.8]: https://github.com/sepandhaghighi/clox/compare/v0.7...v0.8
[0.7]: https://github.com/sepandhaghighi/clox/compare/v0.6...v0.7
[0.6]: https://github.com/sepandhaghighi/clox/compare/v0.5...v0.6
[0.5]: https://github.com/sepandhaghighi/clox/compare/v0.4...v0.5
[0.4]: https://github.com/sepandhaghighi/clox/compare/v0.3...v0.4
[0.3]: https://github.com/sepandhaghighi/clox/compare/v0.2...v0.3
[0.2]: https://github.com/sepandhaghighi/clox/compare/v0.1...v0.2
[0.1]: https://github.com/sepandhaghighi/clox/compare/e9b49e2...v0.1



